==> Google-Ads-GoogleAds-Client-26.0.0.tar.gz: Google-Ads-GoogleAds-Client-26.0.0/lib/Google/Ads/GoogleAds/V19/Enums/AdvertisingChannelSubTypeEnum.pm <==
# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V19::Enums::AdvertisingChannelSubTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED                       => "UNSPECIFIED",
  UNKNOWN                           => "UNKNOWN",
  SEARCH_MOBILE_APP                 => "SEARCH_MOBILE_APP",
  DISPLAY_MOBILE_APP                => "DISPLAY_MOBILE_APP",
  SEARCH_EXPRESS                    => "SEARCH_EXPRESS",
  DISPLAY_EXPRESS                   => "DISPLAY_EXPRESS",
  SHOPPING_SMART_ADS                => "SHOPPING_SMART_ADS",
  DISPLAY_GMAIL_AD                  => "DISPLAY_GMAIL_AD",
  DISPLAY_SMART_CAMPAIGN            => "DISPLAY_SMART_CAMPAIGN",
  VIDEO_ACTION                      => "VIDEO_ACTION",
  VIDEO_NON_SKIPPABLE               => "VIDEO_NON_SKIPPABLE",
  APP_CAMPAIGN                      => "APP_CAMPAIGN",
  APP_CAMPAIGN_FOR_ENGAGEMENT       => "APP_CAMPAIGN_FOR_ENGAGEMENT",
  LOCAL_CAMPAIGN                    => "LOCAL_CAMPAIGN",
  SHOPPING_COMPARISON_LISTING_ADS   => "SHOPPING_COMPARISON_LISTING_ADS",
  SMART_CAMPAIGN                    => "SMART_CAMPAIGN",
  VIDEO_SEQUENCE                    => "VIDEO_SEQUENCE",
  APP_CAMPAIGN_FOR_PRE_REGISTRATION => "APP_CAMPAIGN_FOR_PRE_REGISTRATION",
  VIDEO_REACH_TARGET_FREQUENCY      => "VIDEO_REACH_TARGET_FREQUENCY",
  TRAVEL_ACTIVITIES                 => "TRAVEL_ACTIVITIES"
];

1;

==> Google-Ads-GoogleAds-Client-29.0.1.tar.gz: Google-Ads-GoogleAds-Client-29.0.1/lib/Google/Ads/GoogleAds/V19/Enums/AdvertisingChannelSubTypeEnum.pm <==
# Copyright 2020, Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

package Google::Ads::GoogleAds::V19::Enums::AdvertisingChannelSubTypeEnum;

use strict;
use warnings;

use Const::Exporter enums => [
  UNSPECIFIED                       => "UNSPECIFIED",
  UNKNOWN                           => "UNKNOWN",
  SEARCH_MOBILE_APP                 => "SEARCH_MOBILE_APP",
  DISPLAY_MOBILE_APP                => "DISPLAY_MOBILE_APP",
  SEARCH_EXPRESS                    => "SEARCH_EXPRESS",
  DISPLAY_EXPRESS                   => "DISPLAY_EXPRESS",
  SHOPPING_SMART_ADS                => "SHOPPING_SMART_ADS",
  DISPLAY_GMAIL_AD                  => "DISPLAY_GMAIL_AD",
  DISPLAY_SMART_CAMPAIGN            => "DISPLAY_SMART_CAMPAIGN",
  VIDEO_ACTION                      => "VIDEO_ACTION",
  VIDEO_NON_SKIPPABLE               => "VIDEO_NON_SKIPPABLE",
  APP_CAMPAIGN                      => "APP_CAMPAIGN",
  APP_CAMPAIGN_FOR_ENGAGEMENT       => "APP_CAMPAIGN_FOR_ENGAGEMENT",
  LOCAL_CAMPAIGN                    => "LOCAL_CAMPAIGN",
  SHOPPING_COMPARISON_LISTING_ADS   => "SHOPPING_COMPARISON_LISTING_ADS",
  SMART_CAMPAIGN                    => "SMART_CAMPAIGN",
  VIDEO_SEQUENCE                    => "VIDEO_SEQUENCE",
  APP_CAMPAIGN_FOR_PRE_REGISTRATION => "APP_CAMPAIGN_FOR_PRE_REGISTRATION",
  VIDEO_REACH_TARGET_FREQUENCY      => "VIDEO_REACH_TARGET_FREQUENCY",
  TRAVEL_ACTIVITIES                 => "TRAVEL_ACTIVITIES",
  YOUTUBE_AUDIO                     => "YOUTUBE_AUDIO"
];

1;
